@@ -1,4 +1,5 @@
 import os
+import shlex
 import shutil
 import subprocess as sp
 from importlib import resources
@@ -25,13 +26,28 @@ def load_user_config():
         return load_user_config()
 
 
+USER_CONFIG = load_user_config()
+
+
+def get_alias(command):
+    try:
+        return USER_CONFIG["aliases"][command]
+    except KeyError:
+        return command
+
+
 def clean(git):
     click.secho(str(git), fg="blue")
     sp.run(
         "git status".split(),
         cwd=git,
     )
-    sp.run(click.prompt(click.style(f"{git}$ ", fg="blue")).split(), cwd=git)
+    command = get_alias(click.prompt(click.style(f"{git}$ ", fg="blue")))
+    try:
+        click.echo(f"Running command: {command}")
+        sp.run(shlex.split(command), cwd=git)
+    except FileNotFoundError:
+        click.echo(f"COMMAND NOT FOUND: {command}")
     return get_status(git)
 
 
@@ -65,22 +81,20 @@ def get_status(git):
 @click.command()
 def main():
     """Get the status of all your gits in one command!"""
-    config = load_user_config()
-
     try:
-        assert config is not None
+        assert USER_CONFIG is not None
 
         gits = set()
         try:
             gits = {
                 dir
-                for dir in Path(config.get("gits_folder")).iterdir()
+                for dir in Path(USER_CONFIG.get("gits_folder")).iterdir()
                 if dir.is_dir()
             }
         except TypeError:
             pass
 
-        gits |= {Path(dir) for dir in config.get("individual_gits", [])}
+        gits |= {Path(dir) for dir in USER_CONFIG.get("individual_gits", [])}
 
         assert gits != set()
 
